--[[
BossPanel - Factions
a port of Titan Panel [Factions] by Corgi
]]--

BossPanel_Factions = BossPanelPlugin:new({
	name          = BossPanel_FactionsLocals.NAME,
	description   = BossPanel_FactionsLocals.DESCRIPTION,
	version       = "0.0.2",
	releaseDate   = "03-22-2006",
	aceCompatible = 103,
	author        = "Corgi",
	email         = "corgiwow@gmail.com",
	website       = "http://corgi.wowinterface.com",
	category      = "interface",
	db            = AceDatabase:new("BossPanel_FactionsDB"),
	defaults      = {
		showPercent = FALSE,
	},
	cmd           = AceChatCmd:new(BossPanel_FactionsLocals.COMMANDS, BossPanel_FactionsLocals.CMD_OPTIONS),
	loc 		  = BossPanel_FactionsLocals,
	hasIcon       = TRUE,
	hasNoText	  = TRUE,
	
	-- Methods
	
	Enable = function(self) 
	  self:RegisterEvent("UPDATE_FACTION","Update")
	end,
   
	OnClick = function(self) 
      ToggleCharacter("ReputationFrame")
	end,
	
	IsShowingPercent = function(self)
		return self.data.showPercent
	end,
	
	ToggleShowingPercent = function(self, loud)
		self.data.showPercent = not self.data.showPercent
		if loud then
			self.cmd:status(self.loc.ARGUMENT_PERCENT, self.data.showPercent and 1 or 0, BossPanelLocals.MAP_ONOFF)
		end
		self:Update()
		return self.data.showPercent
	end,
	
	Report = function(self)
		self.cmd:report({
			{text=self.loc.ARGUMENT_PERCENT, val=(self:IsShowingPercent() and 1 or 0), map=BossPanelLocals.MAP_ONOFF},
		})
	end,
	
	MenuSettings = function(self)
		UIDropDownMenu_AddButton({
			text = self.loc.MENU_SHOW_AS_PERCENTAGE,
			func = function()
				self:ToggleShowingPercent()
			end,
			checked = self:IsShowingPercent(),
			keepShowOnClick = TRUE
		})
	end,
	
	UpdateTooltip = function(self)

		local NumFactions = GetNumFactions();

		local faction_name, faction_description, faction_standingID, faction_barMin, faction_barMax, faction_barValue, faction_atWarWith
		local faction_canToggleAtWar, faction_isHeader, faction_isCollapsed

		local factionIndex
		local standingText = ""
		
		BossPanelTooltip:AddLine(self.loc.TOOLTIP_TITLE)
		
		for factionIndex=1, NumFactions do
			
			local tooltipRichText = ""
			
			faction_name, faction_description, faction_standingID, faction_barMin, faction_barMax, faction_barValue, faction_atWarWith, faction_canToggleAtWar, faction_isHeader, faction_isCollapsed = GetFactionInfo(factionIndex)
	
			if ( not faction_isHeader ) then
			
				standingText = self:FindRep(faction_standingID)
				
				if ( self:IsShowingPercent() ) then
					local bval = math.floor( ((faction_barValue - faction_barMin) / (faction_barMax - faction_barMin)) * 100)
					tooltipRichText = standingText.." ("..bval.."%)"
					BossPanelTooltip:AddDoubleLine(faction_name..":", tooltipRichText, 0, 1, 0, 1, 1, 0)
				else
					tooltipRichText = standingText.." ("..faction_barValue - faction_barMin.."/"..faction_barMax - faction_barMin..")"
					BossPanelTooltip:AddDoubleLine(faction_name..":", tooltipRichText, 0, 1, 0, 1, 1, 0)	
				end
			else
				BossPanelTooltip:AddLine(faction_name, 1, 1, 1)
			end
		end
	end,
	
	FindRep = function(self, standingID)
		local standingText = ""
		if ( standingID == 0 ) then
			standingText = UNKNOWN -- unknown
		elseif ( standingID == 1 ) then
			standingText = self.loc.FactionTextHated 	-- hated
		elseif ( standingID == 2) then
			standingText = self.loc.FactionTextHostile 	-- hostile
		elseif ( standingID == 3) then
			standingText = self.loc.FactionTextUnfriendly -- unfriendly
		elseif ( standingID == 4) then
			standingText = self.loc.FactionTextNeutral 	-- neutral
		elseif ( standingID == 5) then
			standingText = self.loc.FactionTextFriendly -- friendly
		elseif ( standingID == 6) then
			standingText = self.loc.FactionTextHonored 	-- honored
		elseif ( standingID == 7) then
			standingText = self.loc.FactionTextRevered 	-- revered
		elseif ( standingID == 8) then
			standingText = self.loc.FactionTextExalted 	-- exalted
		end
		return standingText
	end,
})

BossPanel_Factions:RegisterForLoad()